<h1 align="center">immichpy</h1>
<h3 align="center">The stable, typed Python API layer for <a href="https://immich.app">Immich</a> automation and integrations.</h3>
<p align="center">
    <a href="https://pypi.org/project/immichpy" target="_blank">
        <img src="https://img.shields.io/pypi/v/immichpy?color=blue&label=pypi%20package" alt="Package version">
    </a>
    <a href="https://pypi.org/project/immichpy" target="_blank">
        <img src="https://img.shields.io/pypi/dm/immichpy?color=blue" alt="Downloads">
    </a>
    <a href="https://pypi.org/project/immichpy" target="_blank">
        <img src="https://img.shields.io/pypi/pyversions/immichpy.svg?color=blue" alt="Supported Python versions">
    </a>
    <a href="https://github.com/immich-app/immich/releases" target="_blank">
        <img src="https://img.shields.io/badge/dynamic/regex?url=https://raw.githubusercontent.com/timonrieger/immichpy/main/IMMICH-VERSION&search=(.*)&replace=v2.4.1%20-%20$1&label=supported%20Immich%20versions&color=blue" alt="Supported Immich version">
    </a>
    <img src="https://img.shields.io/github/actions/workflow/status/timonrieger/immichpy/cd.yml?branch=main&event=push&logo=github&label=Continuous%20Delivery&color=blue" alt="CD Status">
</p>

> [!NOTE]
> This project is not affiliated with or endorsed by Immich.

## Documentation

For full documentation, visit [immichpy.timonrieger.de](https://immichpy.timonrieger.de).

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.
